@@ -181,7 +181,7 @@ predict.poisson <- function(object, newdata, lambda.idx = c(1:3), p.pred.idx = c
   pred.n = nrow(newdata)
   lambda.n = length(lambda.idx)
   p.pred.n = length(p.pred.idx)
-  intcpt = matrix(rep(object$intercept[,lambda.idx],pred.n), nrow=pred.n,
+  intcpt = matrix(rep(object$intercept[lambda.idx],pred.n), nrow=pred.n,
                   ncol=lambda.n, byrow=T)
   res = newdata%*%object$beta[,lambda.idx] + intcpt
 
